Unit RelayControlForm;

Interface

Uses
    Windows,
    Messages,
    SysUtils,
    Classes,
    Graphics,
    Controls,
    Forms,
    Dialogs,
    StdCtrls,
    ExtCtrls,
    CPort,
    CPortCtl,
    Buttons;

Type
    TFormRelayControl = class(TForm)
      Memo           : TMemo;
      ButtonOpen     : TButton;
      Button_Settings: TButton;
      Edit_Data      : TEdit;
      Button_Send    : TButton;
      NewLine_CB     : TCheckBox;
      Panel1         : TPanel;
      ButtonStore    : TButton;
      ButtonLoad     : TButton;
      ComLed1        : TComLed;
      ComLed2        : TComLed;
      ComLed3        : TComLed;
      ComLed4        : TComLed;
      Label2         : TLabel;
      Label3         : TLabel;
      Label4         : TLabel;
      Label5         : TLabel;
      ComLed5        : TComLed;
      ComLed6        : TComLed;
      Label1         : TLabel;
      Label6         : TLabel;
      ButtonAllOff   : TButton;
      ButtonAllOn    : TButton;
      ButtonRelay1   : TSpeedButton;
      ButtonRelay3   : TSpeedButton;
      ButtonRelay2   : TSpeedButton;
      ButtonRelay4   : TSpeedButton;

      Procedure ButtonOpenClick     (Sender : TObject);
      Procedure Button_SettingsClick(Sender : TObject);
      Procedure Button_SendClick    (Sender : TObject);
      Procedure ComPortOpen         (Sender : TObject);
      Procedure ComPortClose        (Sender : TObject);
      Procedure ComPortxRxChar      (Sender : TObject; Count : Integer);
      Procedure ButtonLoadClick     (Sender : TObject);
      Procedure ButtonStoreClick    (Sender : TObject);
      Procedure FormShow            (Sender : TObject);
      Procedure ButtonClick         (Sender : TObject);
      Procedure ButtonLetterClick   (Sender : TObject);
      Procedure ButtonAllOffClick   (Sender : TObject);
      Procedure ButtonAllOnClick    (Sender : TObject);
      Procedure ButtonRelay2Click   (Sender : TObject);
      Procedure ButtonRelay3Click   (Sender : TObject);
      Procedure ButtonRelay4Click   (Sender : TObject);
      Procedure ButtonRelay1Click       (Sender : TObject);
      Procedure FormCreate          (Sender : TObject);
    Private
      { Private declarations }
    Public
      { Public declarations }
    End;

Var
    FormRelayControl: TFormRelayControl;
    ComPort : TComPort;

Implementation
{...............................................................................}
{$R *.DFM}
{...............................................................................}
Procedure TFormRelayControl.FormCreate (Sender : TObject);
Begin
    ComPort := TComPort.Create(FormRelayControl);
End;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.FormShow (Sender : TObject);
Begin
    ComPort.BaudRate     := br9600;
    ComPort.StopBits     := sbOneStopBit;
    ComPort.DataBits     := dbEight;
    ComPort.Port         := 'Com3';

    ComPort.OnAfterClose := ComPortClose;
    ComPort.OnAfterOpen  := ComPortOpen;
    ComPort.OnRxChar     := ComPortxRxChar;

    ComPort.Open;
End;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.ButtonOpenClick (Sender : TObject);
Begin
    If ComPort.Connected Then ComPort.Close
                         Else ComPort.Open;
End;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.Button_SettingsClick (Sender : TObject);
Begin
    ComPort.ShowSetupDialog;
End;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.Button_SendClick (Sender : TObject);
Var
    Str : String;
Begin
    Str := Edit_Data.Text;

    If NewLine_CB.Checked Then Str := Str + #13#10;

    ComPort.WriteStr (Str);
End;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.ComPortOpen (Sender : TObject);
Begin
    ButtonOpen.Caption := 'Close';
End;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.ComPortClose (Sender : TObject);
Begin
  If ButtonOpen <> Nil Then ButtonOpen.Caption := 'Open';
End;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.ComPortxRxChar (Sender : TObject; Count : Integer);
Var
    Str : String;
Begin
    ComPort.ReadStr (Str, Count);

    Memo.Text := Memo.Text + Str;
End;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.ButtonLoadClick (Sender : TObject);
Begin
    ComPort.LoadSettings (stRegistry, 'HKEY_LOCAL_MACHINE\Software\Dejan');
End;
{...............................................................................}

{...............................................................................}
procedure TFormRelayControl.ButtonStoreClick(Sender: TObject);
begin
    ComPort.StoreSettings(stRegistry, 'HKEY_LOCAL_MACHINE\Software\Dejan');
end;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.ButtonClick (Sender : TObject);
Var
    S : String;
Begin
    S := TButton (Sender).Caption;
    ComPort.WriteStr (S);
End;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.ButtonLetterClick (Sender : TObject);
Var
    i : Integer;
    S : String;
Begin
    For i := 0 To 16 Do
    Begin
        S := TButton (Sender).Caption + IntToStr (i);
        ComPort.WriteStr (S);

        Sleep (100);
    End;

    Memo.Lines.Add (TButton (Sender).Caption + ' Complete');
End;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.ButtonAllOffClick (Sender : TObject);
Begin
    ComPort.WriteStr('C' + Chr(0));   //All off
End;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.ButtonAllOnClick (Sender : TObject);
Begin
    ComPort.WriteStr('C' + Chr($FF));   //All on
End;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.ButtonRelay1Click (Sender : TObject);
Begin
    ComPort.WriteStr ('C' + Chr ($01)); //1 only
End;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.ButtonRelay2Click (Sender : TObject);
Begin
    ComPort.WriteStr ('C' + Chr ($02)); //2 only
End;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.ButtonRelay3Click (Sender : TObject);
Begin
    ComPort.WriteStr ('C' + Chr ($04)); //3 only
End;
{...............................................................................}

{...............................................................................}
Procedure TFormRelayControl.ButtonRelay4Click (Sender : TObject);
Begin
    ComPort.WriteStr ('C' + Chr ($08)); //4 only
End;
{...............................................................................}

{...............................................................................}

End.

